from django.apps import AppConfig


class GmailOauthBackendConfig(AppConfig):
    default_auto_field = 'django.db.models.BigAutoField'
    name = 'gmail_oauth_backend'
    verbose_name = 'Gmail OAuth Backend'